==> jc-1.4.0.tar.gz: java/awt/AWTKeyStroke__243.h <==
// final class java.awt.AWTKeyStroke$3

// class file dependencies
// @dep_class 1fa489672b80881c java_awt_AWTKeyStroke__243
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_AWTKeyStroke__243_H_
#define _JC_java_awt_AWTKeyStroke__243_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_AWTKeyStroke__243$sub_refs	_jc_java_awt_AWTKeyStroke__243$sub_refs;
typedef struct _jc_java_awt_AWTKeyStroke__243$sub_nonrefs	_jc_java_awt_AWTKeyStroke__243$sub_nonrefs;
typedef struct _jc_java_awt_AWTKeyStroke__243$refs	_jc_java_awt_AWTKeyStroke__243$refs;
typedef struct _jc_java_awt_AWTKeyStroke__243$nonrefs	_jc_java_awt_AWTKeyStroke__243$nonrefs;
typedef struct _jc_java_awt_AWTKeyStroke__243$object	_jc_java_awt_AWTKeyStroke__243$object;

typedef const struct _jc_java_awt_AWTKeyStroke__243$vmethods	_jc_java_awt_AWTKeyStroke__243$vmethods;
typedef const struct _jc_java_awt_AWTKeyStroke__243$vtable	_jc_java_awt_AWTKeyStroke__243$vtable;
typedef const struct _jc_java_awt_AWTKeyStroke__243$vtype	_jc_java_awt_AWTKeyStroke__243$vtype;

// Constructors
extern void _jc_java_awt_AWTKeyStroke__243$method$_init$288d3bcb8f0d1932(_jc_env *, struct _jc_java_awt_AWTKeyStroke__243$object *, struct _jc_java_lang_Class$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_AWTKeyStroke__243$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_java_awt_AWTKeyStroke__243$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_AWTKeyStroke__243$method_info$run$b190d7b16d5785b8;

// Virtual methods structure
struct _jc_java_awt_AWTKeyStroke__243$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_java_awt_AWTKeyStroke__243$object *);
};

// Vtable
struct _jc_java_awt_AWTKeyStroke__243$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AWTKeyStroke__243$vmethods	java_awt_AWTKeyStroke__243;
};

// Vtype
struct _jc_java_awt_AWTKeyStroke__243$vtype {
	_jc_type			type;
	_jc_java_awt_AWTKeyStroke__243$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_AWTKeyStroke__243$sub_refs {
	struct _jc_java_lang_Class$object	*val__24subclass;
};

// Reference instance fields (object)
struct _jc_java_awt_AWTKeyStroke__243$refs {
    _jc_java_awt_AWTKeyStroke__243$sub_refs	java_awt_AWTKeyStroke__243;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_AWTKeyStroke__243$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_AWTKeyStroke__243$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AWTKeyStroke__243$sub_nonrefs	java_awt_AWTKeyStroke__243;
};

// Object instance structure
struct _jc_java_awt_AWTKeyStroke__243$object {
	_jc_java_awt_AWTKeyStroke__243$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_AWTKeyStroke__243$vtype	*vtype;
	_jc_java_awt_AWTKeyStroke__243$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_AWTKeyStroke__243$vtype _jc_java_awt_AWTKeyStroke__243$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_AWTKeyStroke__243, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_AWTKeyStroke__243$class_object;

#endif	/* _JC_java_awt_AWTKeyStroke__243_H_ */

==> jc-1.4.5.tar.gz: java/awt/AWTKeyStroke__243.h <==
// final class java.awt.AWTKeyStroke$3

// class file dependencies
// @dep_class 899c1f6488358a9d java_awt_AWTKeyStroke__243
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_AWTKeyStroke__243_H_
#define _JC_java_awt_AWTKeyStroke__243_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_AWTKeyStroke__243$sub_refs	_jc_java_awt_AWTKeyStroke__243$sub_refs;
typedef struct _jc_java_awt_AWTKeyStroke__243$sub_nonrefs	_jc_java_awt_AWTKeyStroke__243$sub_nonrefs;
typedef struct _jc_java_awt_AWTKeyStroke__243$refs	_jc_java_awt_AWTKeyStroke__243$refs;
typedef struct _jc_java_awt_AWTKeyStroke__243$nonrefs	_jc_java_awt_AWTKeyStroke__243$nonrefs;
typedef struct _jc_java_awt_AWTKeyStroke__243$object	_jc_java_awt_AWTKeyStroke__243$object;

typedef const struct _jc_java_awt_AWTKeyStroke__243$vmethods	_jc_java_awt_AWTKeyStroke__243$vmethods;
typedef const struct _jc_java_awt_AWTKeyStroke__243$vtable	_jc_java_awt_AWTKeyStroke__243$vtable;
typedef const struct _jc_java_awt_AWTKeyStroke__243$vtype	_jc_java_awt_AWTKeyStroke__243$vtype;

// Constructors
extern void _jc_java_awt_AWTKeyStroke__243$method$_init$288d3bcb8f0d1932(_jc_env *, struct _jc_java_awt_AWTKeyStroke__243$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_AWTKeyStroke__243$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_java_awt_AWTKeyStroke__243$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_AWTKeyStroke__243$method_info$run$b190d7b16d5785b8;

// Virtual methods structure
struct _jc_java_awt_AWTKeyStroke__243$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_java_awt_AWTKeyStroke__243$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_AWTKeyStroke__243$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AWTKeyStroke__243$vmethods	java_awt_AWTKeyStroke__243;
};

// Vtype
struct _jc_java_awt_AWTKeyStroke__243$vtype {
	_jc_type			type;
	_jc_java_awt_AWTKeyStroke__243$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_AWTKeyStroke__243$sub_refs {
	struct _jc_java_lang_Class$object	*val__24subclass;
};

// Reference instance fields (object)
struct _jc_java_awt_AWTKeyStroke__243$refs {
    _jc_java_awt_AWTKeyStroke__243$sub_refs	java_awt_AWTKeyStroke__243;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_AWTKeyStroke__243$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_AWTKeyStroke__243$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AWTKeyStroke__243$sub_nonrefs	java_awt_AWTKeyStroke__243;
};

// Object instance structure
struct _jc_java_awt_AWTKeyStroke__243$object {
	_jc_java_awt_AWTKeyStroke__243$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_AWTKeyStroke__243$vtype	*vtype;
	_jc_java_awt_AWTKeyStroke__243$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_AWTKeyStroke__243$vtype _jc_java_awt_AWTKeyStroke__243$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_AWTKeyStroke__243, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_AWTKeyStroke__243$class_object;

#endif	/* _JC_java_awt_AWTKeyStroke__243_H_ */
